# openapi-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint


# Defining host is optional and default to http://localhost
configuration.host = "http://localhost"
# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.DefaultApi(api_client)
    add_instance_pool_member = openapi_client.AddInstancePoolMember() # AddInstancePoolMember | 

    try:
        # Add Instance To Pool
        api_instance.add_instance_to_pool_api_v2_instancepools_add_instance_post(add_instance_pool_member)
    except ApiException as e:
        print("Exception when calling DefaultApi->add_instance_to_pool_api_v2_instancepools_add_instance_post: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**add_instance_to_pool_api_v2_instancepools_add_instance_post**](docs/DefaultApi.md#add_instance_to_pool_api_v2_instancepools_add_instance_post) | **POST** /api/v2/instancepools/add_instance | Add Instance To Pool
*DefaultApi* | [**alter_organization_collaborator_api_v2_organization_collaborators_identity_id_put**](docs/DefaultApi.md#alter_organization_collaborator_api_v2_organization_collaborators_identity_id_put) | **PUT** /api/v2/organization_collaborators/{identity_id} | Alter Organization Collaborator
*DefaultApi* | [**alter_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_put**](docs/DefaultApi.md#alter_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_put) | **PUT** /api/v2/projects/{project_id}/collaborators/{role_or_identity_id} | Alter Project Collaborator
*DefaultApi* | [**apis_enable_api_v2_clouds_gcp_enable_api_project_id_api_name_get**](docs/DefaultApi.md#apis_enable_api_v2_clouds_gcp_enable_api_project_id_api_name_get) | **GET** /api/v2/clouds/gcp/enable/api/{project_id}/{api_name} | Apis Enable
*DefaultApi* | [**batch_create_invitations_api_v2_organization_invitations_batch_create_post**](docs/DefaultApi.md#batch_create_invitations_api_v2_organization_invitations_batch_create_post) | **POST** /api/v2/organization_invitations/batch_create | Batch Create Invitations
*DefaultApi* | [**cancel_build_api_v2_builds_build_id_cancel_post**](docs/DefaultApi.md#cancel_build_api_v2_builds_build_id_cancel_post) | **POST** /api/v2/builds/{build_id}/cancel | Cancel Build
*DefaultApi* | [**cancel_startup_api_v2_sessions_session_id_cancel_startup_post**](docs/DefaultApi.md#cancel_startup_api_v2_sessions_session_id_cancel_startup_post) | **POST** /api/v2/sessions/{session_id}/cancel_startup | Cancel Startup
*DefaultApi* | [**change_password_api_v2_users_change_password_post**](docs/DefaultApi.md#change_password_api_v2_users_change_password_post) | **POST** /api/v2/users/change_password | Change Password
*DefaultApi* | [**check_availability_api_v2_organizations_check_availability_get**](docs/DefaultApi.md#check_availability_api_v2_organizations_check_availability_get) | **GET** /api/v2/organizations/check_availability | Check Availability
*DefaultApi* | [**check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get**](docs/DefaultApi.md#check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get) | **GET** /api/v2/userinfo/check_is_feature_flag_on | Check Is Feature Flag On
*DefaultApi* | [**create_anyscale_service_account_api_v2_clouds_gcp_create_anyscale_service_account_target_project_id_get**](docs/DefaultApi.md#create_anyscale_service_account_api_v2_clouds_gcp_create_anyscale_service_account_target_project_id_get) | **GET** /api/v2/clouds/gcp/create/anyscale_service_account/{target_project_id} | Create Anyscale Service Account
*DefaultApi* | [**create_application_template_api_v2_application_templates_post**](docs/DefaultApi.md#create_application_template_api_v2_application_templates_post) | **POST** /api/v2/application_templates/ | Create Application Template
*DefaultApi* | [**create_autoscaler_service_account_api_v2_clouds_gcp_create_autoscaler_service_account_project_id_get**](docs/DefaultApi.md#create_autoscaler_service_account_api_v2_clouds_gcp_create_autoscaler_service_account_project_id_get) | **GET** /api/v2/clouds/gcp/create/autoscaler_service_account/{project_id} | Create Autoscaler Service Account
*DefaultApi* | [**create_build_api_v2_builds_post**](docs/DefaultApi.md#create_build_api_v2_builds_post) | **POST** /api/v2/builds/ | Create Build
*DefaultApi* | [**create_cloud_api_v2_clouds_post**](docs/DefaultApi.md#create_cloud_api_v2_clouds_post) | **POST** /api/v2/clouds/ | Create Cloud
*DefaultApi* | [**create_compute_template_api_v2_compute_templates_post**](docs/DefaultApi.md#create_compute_template_api_v2_compute_templates_post) | **POST** /api/v2/compute_templates/ | Create Compute Template
*DefaultApi* | [**create_connect_session_api_v2_sessions_create_connect_session_post**](docs/DefaultApi.md#create_connect_session_api_v2_sessions_create_connect_session_post) | **POST** /api/v2/sessions/create_connect_session | Create Connect Session
*DefaultApi* | [**create_from_github_api_v2_projects_create_from_github_post**](docs/DefaultApi.md#create_from_github_api_v2_projects_create_from_github_post) | **POST** /api/v2/projects/create_from_github | Create From Github
*DefaultApi* | [**create_invitation_api_v2_organization_invitations_post**](docs/DefaultApi.md#create_invitation_api_v2_organization_invitations_post) | **POST** /api/v2/organization_invitations/ | Create Invitation
*DefaultApi* | [**create_new_session_api_v2_sessions_create_new_session_post**](docs/DefaultApi.md#create_new_session_api_v2_sessions_create_new_session_post) | **POST** /api/v2/sessions/create_new_session | Create New Session
*DefaultApi* | [**create_nodes_api_v2_instances_post**](docs/DefaultApi.md#create_nodes_api_v2_instances_post) | **POST** /api/v2/instances/ | Create Nodes
*DefaultApi* | [**create_organization_collaborator_api_v2_projects_project_id_collaborators_organization_post**](docs/DefaultApi.md#create_organization_collaborator_api_v2_projects_project_id_collaborators_organization_post) | **POST** /api/v2/projects/{project_id}/collaborators/organization | Create Organization Collaborator
*DefaultApi* | [**create_project_api_v2_projects_post**](docs/DefaultApi.md#create_project_api_v2_projects_post) | **POST** /api/v2/projects/ | Create Project
*DefaultApi* | [**create_project_collaborator_api_v2_projects_project_id_collaborators_users_post**](docs/DefaultApi.md#create_project_collaborator_api_v2_projects_project_id_collaborators_users_post) | **POST** /api/v2/projects/{project_id}/collaborators/users | Create Project Collaborator
*DefaultApi* | [**create_session_command_api_v2_sessions_session_id_create_session_command_post**](docs/DefaultApi.md#create_session_command_api_v2_sessions_session_id_create_session_command_post) | **POST** /api/v2/sessions/{session_id}/create_session_command | Create Session Command
*DefaultApi* | [**create_snapshot_api_v2_snapshots_post**](docs/DefaultApi.md#create_snapshot_api_v2_snapshots_post) | **POST** /api/v2/snapshots/ | Create Snapshot
*DefaultApi* | [**create_web_terminal_api_v2_sessions_session_id_web_terminals_post**](docs/DefaultApi.md#create_web_terminal_api_v2_sessions_session_id_web_terminals_post) | **POST** /api/v2/sessions/{session_id}/web_terminals | Create Web Terminal
*DefaultApi* | [**delete_application_template_api_v2_application_templates_application_template_id_delete**](docs/DefaultApi.md#delete_application_template_api_v2_application_templates_application_template_id_delete) | **DELETE** /api/v2/application_templates/{application_template_id} | Delete Application Template
*DefaultApi* | [**delete_build_api_v2_builds_build_id_delete**](docs/DefaultApi.md#delete_build_api_v2_builds_build_id_delete) | **DELETE** /api/v2/builds/{build_id} | Delete Build
*DefaultApi* | [**delete_cloud_api_v2_clouds_cloud_id_delete**](docs/DefaultApi.md#delete_cloud_api_v2_clouds_cloud_id_delete) | **DELETE** /api/v2/clouds/{cloud_id} | Delete Cloud
*DefaultApi* | [**delete_compute_template_api_v2_compute_templates_template_id_delete**](docs/DefaultApi.md#delete_compute_template_api_v2_compute_templates_template_id_delete) | **DELETE** /api/v2/compute_templates/{template_id} | Delete Compute Template
*DefaultApi* | [**delete_project_api_v2_projects_project_id_delete**](docs/DefaultApi.md#delete_project_api_v2_projects_project_id_delete) | **DELETE** /api/v2/projects/{project_id} | Delete Project
*DefaultApi* | [**delete_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_delete**](docs/DefaultApi.md#delete_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_delete) | **DELETE** /api/v2/projects/{project_id}/collaborators/{role_or_identity_id} | Delete Project Collaborator
*DefaultApi* | [**delete_session_api_v2_sessions_session_id_delete**](docs/DefaultApi.md#delete_session_api_v2_sessions_session_id_delete) | **DELETE** /api/v2/sessions/{session_id} | Delete Session
*DefaultApi* | [**delete_snapshot_api_v2_snapshots_snapshot_id_delete**](docs/DefaultApi.md#delete_snapshot_api_v2_snapshots_snapshot_id_delete) | **DELETE** /api/v2/snapshots/{snapshot_id} | Delete Snapshot
*DefaultApi* | [**delete_web_terminals_api_v2_sessions_session_id_web_terminals_terminal_id_delete**](docs/DefaultApi.md#delete_web_terminals_api_v2_sessions_session_id_web_terminals_terminal_id_delete) | **DELETE** /api/v2/sessions/{session_id}/web_terminals/{terminal_id} | Delete Web Terminals
*DefaultApi* | [**deregister_autosync_session_api_v2_autosync_sessions_autosync_session_id_delete**](docs/DefaultApi.md#deregister_autosync_session_api_v2_autosync_sessions_autosync_session_id_delete) | **DELETE** /api/v2/autosync_sessions/{autosync_session_id} | Deregister Autosync Session
*DefaultApi* | [**describe_session_api_v2_sessions_session_id_describe_get**](docs/DefaultApi.md#describe_session_api_v2_sessions_session_id_describe_get) | **GET** /api/v2/sessions/{session_id}/describe | Describe Session
*DefaultApi* | [**echo_ip_api_v2_health_echo_ip_get**](docs/DefaultApi.md#echo_ip_api_v2_health_echo_ip_get) | **GET** /api/v2/health/echo_ip | Echo Ip
*DefaultApi* | [**execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post**](docs/DefaultApi.md#execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post) | **POST** /api/v2/sessions/{session_id}/execute_interactive_command | Execute Interactive Command
*DefaultApi* | [**execute_shell_command_api_v2_sessions_session_id_execute_shell_command_post**](docs/DefaultApi.md#execute_shell_command_api_v2_sessions_session_id_execute_shell_command_post) | **POST** /api/v2/sessions/{session_id}/execute_shell_command | Execute Shell Command
*DefaultApi* | [**external_ip_api_v2_instances_instance_id_external_ip_get**](docs/DefaultApi.md#external_ip_api_v2_instances_instance_id_external_ip_get) | **GET** /api/v2/instances/{instance_id}/external_ip | External Ip
*DefaultApi* | [**find_cloud_by_name_api_v2_clouds_find_by_name_post**](docs/DefaultApi.md#find_cloud_by_name_api_v2_clouds_find_by_name_post) | **POST** /api/v2/clouds/find_by_name | Find Cloud By Name
*DefaultApi* | [**find_project_by_project_name_api_v2_projects_find_by_name_get**](docs/DefaultApi.md#find_project_by_project_name_api_v2_projects_find_by_name_get) | **GET** /api/v2/projects/find_by_name | Find Project By Project Name
*DefaultApi* | [**find_with_invitation_api_v2_organizations_find_with_invitation_get**](docs/DefaultApi.md#find_with_invitation_api_v2_organizations_find_with_invitation_get) | **GET** /api/v2/organizations/find_with_invitation | Find With Invitation
*DefaultApi* | [**find_with_public_identifier_api_v2_organizations_find_with_public_identifier_get**](docs/DefaultApi.md#find_with_public_identifier_api_v2_organizations_find_with_public_identifier_get) | **GET** /api/v2/organizations/find_with_public_identifier | Find With Public Identifier
*DefaultApi* | [**finish_session_command_api_v2_session_commands_session_command_id_finish_post**](docs/DefaultApi.md#finish_session_command_api_v2_session_commands_session_command_id_finish_post) | **POST** /api/v2/session_commands/{session_command_id}/finish | Finish Session Command
*DefaultApi* | [**fork_session_api_v2_sessions_session_id_fork_post**](docs/DefaultApi.md#fork_session_api_v2_sessions_session_id_fork_post) | **POST** /api/v2/sessions/{session_id}/fork | Fork Session
*DefaultApi* | [**gcp_create_cloud_api_v2_clouds_gcp_create_cloud_name_get**](docs/DefaultApi.md#gcp_create_cloud_api_v2_clouds_gcp_create_cloud_name_get) | **GET** /api/v2/clouds/gcp/create/{cloud_name} | Gcp Create Cloud
*DefaultApi* | [**gcp_create_project_api_v2_clouds_gcp_create_project_get**](docs/DefaultApi.md#gcp_create_project_api_v2_clouds_gcp_create_project_get) | **GET** /api/v2/clouds/gcp/create/project | Gcp Create Project
*DefaultApi* | [**get_active_autosync_sessions_for_session_api_v2_autosync_sessions_get**](docs/DefaultApi.md#get_active_autosync_sessions_for_session_api_v2_autosync_sessions_get) | **GET** /api/v2/autosync_sessions/ | Get Active Autosync Sessions For Session
*DefaultApi* | [**get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get**](docs/DefaultApi.md#get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get) | **GET** /api/v2/clouds/anyscale/aws_account | Get Anyscale Aws Account
*DefaultApi* | [**get_anyscale_version_api_v2_userinfo_anyscale_version_get**](docs/DefaultApi.md#get_anyscale_version_api_v2_userinfo_anyscale_version_get) | **GET** /api/v2/userinfo/anyscale_version | Get Anyscale Version
*DefaultApi* | [**get_application_template_api_v2_application_templates_application_template_id_get**](docs/DefaultApi.md#get_application_template_api_v2_application_templates_application_template_id_get) | **GET** /api/v2/application_templates/{application_template_id} | Get Application Template
*DefaultApi* | [**get_build_api_v2_builds_build_id_get**](docs/DefaultApi.md#get_build_api_v2_builds_build_id_get) | **GET** /api/v2/builds/{build_id} | Get Build
*DefaultApi* | [**get_build_logs_api_v2_builds_build_id_logs_get**](docs/DefaultApi.md#get_build_logs_api_v2_builds_build_id_logs_get) | **GET** /api/v2/builds/{build_id}/logs | Get Build Logs
*DefaultApi* | [**get_cloud_api_v2_clouds_cloud_id_get**](docs/DefaultApi.md#get_cloud_api_v2_clouds_cloud_id_get) | **GET** /api/v2/clouds/{cloud_id} | Get Cloud
*DefaultApi* | [**get_cluster_status_api_v2_sessions_session_id_cluster_status_get**](docs/DefaultApi.md#get_cluster_status_api_v2_sessions_session_id_cluster_status_get) | **GET** /api/v2/sessions/{session_id}/cluster_status | Get Cluster Status
*DefaultApi* | [**get_compute_template_api_v2_compute_templates_template_id_get**](docs/DefaultApi.md#get_compute_template_api_v2_compute_templates_template_id_get) | **GET** /api/v2/compute_templates/{template_id} | Get Compute Template
*DefaultApi* | [**get_decorated_actor_api_v2_decorated_actors_actor_id_get**](docs/DefaultApi.md#get_decorated_actor_api_v2_decorated_actors_actor_id_get) | **GET** /api/v2/decorated_actors/{actor_id} | Get Decorated Actor
*DefaultApi* | [**get_decorated_actor_logs_api_v2_decorated_actors_actor_id_logs_get**](docs/DefaultApi.md#get_decorated_actor_logs_api_v2_decorated_actors_actor_id_logs_get) | **GET** /api/v2/decorated_actors/{actor_id}/logs | Get Decorated Actor Logs
*DefaultApi* | [**get_decorated_job_api_v2_decorated_jobs_job_id_get**](docs/DefaultApi.md#get_decorated_job_api_v2_decorated_jobs_job_id_get) | **GET** /api/v2/decorated_jobs/{job_id} | Get Decorated Job
*DefaultApi* | [**get_decorated_job_logs_api_v2_decorated_jobs_job_id_logs_get**](docs/DefaultApi.md#get_decorated_job_logs_api_v2_decorated_jobs_job_id_logs_get) | **GET** /api/v2/decorated_jobs/{job_id}/logs | Get Decorated Job Logs
*DefaultApi* | [**get_decorated_runtime_env_api_v2_decorated_runtime_envs_runtime_env_id_get**](docs/DefaultApi.md#get_decorated_runtime_env_api_v2_decorated_runtime_envs_runtime_env_id_get) | **GET** /api/v2/decorated_runtime_envs/{runtime_env_id} | Get Decorated Runtime Env
*DefaultApi* | [**get_decorated_sessions_api_v2_decorated_sessions_session_id_get**](docs/DefaultApi.md#get_decorated_sessions_api_v2_decorated_sessions_session_id_get) | **GET** /api/v2/decorated_sessions/{session_id} | Get Decorated Sessions
*DefaultApi* | [**get_default_compute_config_api_v2_compute_templates_default_cloud_id_get**](docs/DefaultApi.md#get_default_compute_config_api_v2_compute_templates_default_cloud_id_get) | **GET** /api/v2/compute_templates/default/{cloud_id} | Get Default Compute Config
*DefaultApi* | [**get_execution_logs_api_v2_session_commands_session_command_id_execution_logs_get**](docs/DefaultApi.md#get_execution_logs_api_v2_session_commands_session_command_id_execution_logs_get) | **GET** /api/v2/session_commands/{session_command_id}/execution_logs | Get Execution Logs
*DefaultApi* | [**get_execution_logs_archived_api_v2_session_commands_session_command_id_execution_logs_archived_get**](docs/DefaultApi.md#get_execution_logs_archived_api_v2_session_commands_session_command_id_execution_logs_archived_get) | **GET** /api/v2/session_commands/{session_command_id}/execution_logs_archived | Get Execution Logs Archived
*DefaultApi* | [**get_instance_api_v2_instances_instance_id_get**](docs/DefaultApi.md#get_instance_api_v2_instances_instance_id_get) | **GET** /api/v2/instances/{instance_id} | Get Instance
*DefaultApi* | [**get_invitation_api_v2_organization_invitations_invitation_id_get**](docs/DefaultApi.md#get_invitation_api_v2_organization_invitations_invitation_id_get) | **GET** /api/v2/organization_invitations/{invitation_id} | Get Invitation
*DefaultApi* | [**get_monitor_logs_api_v2_sessions_session_id_monitor_logs_get**](docs/DefaultApi.md#get_monitor_logs_api_v2_sessions_session_id_monitor_logs_get) | **GET** /api/v2/sessions/{session_id}/monitor_logs | Get Monitor Logs
*DefaultApi* | [**get_monitor_logs_archived_api_v2_sessions_session_id_monitor_logs_archived_get**](docs/DefaultApi.md#get_monitor_logs_archived_api_v2_sessions_session_id_monitor_logs_archived_get) | **GET** /api/v2/sessions/{session_id}/monitor_logs_archived | Get Monitor Logs Archived
*DefaultApi* | [**get_node_id_by_external_ip_api_v2_instances_external_ip_get_node_id_by_external_ip_get**](docs/DefaultApi.md#get_node_id_by_external_ip_api_v2_instances_external_ip_get_node_id_by_external_ip_get) | **GET** /api/v2/instances/{external_ip}/get_node_id_by_external_ip | Get Node Id By External Ip
*DefaultApi* | [**get_node_id_by_internal_ip_api_v2_instances_internal_ip_get_node_id_by_internal_ip_get**](docs/DefaultApi.md#get_node_id_by_internal_ip_api_v2_instances_internal_ip_get_node_id_by_internal_ip_get) | **GET** /api/v2/instances/{internal_ip}/get_node_id_by_internal_ip | Get Node Id By Internal Ip
*DefaultApi* | [**get_or_create_cluster_monitor_api_v2_sessions_session_id_get_or_create_cluster_monitor_post**](docs/DefaultApi.md#get_or_create_cluster_monitor_api_v2_sessions_session_id_get_or_create_cluster_monitor_post) | **POST** /api/v2/sessions/{session_id}/get_or_create_cluster_monitor | Get Or Create Cluster Monitor
*DefaultApi* | [**get_ping_external_services_api_v2_sessions_session_id_ping_external_services_get**](docs/DefaultApi.md#get_ping_external_services_api_v2_sessions_session_id_ping_external_services_get) | **GET** /api/v2/sessions/{session_id}/ping_external_services | Get Ping External Services
*DefaultApi* | [**get_project_api_v2_projects_project_id_get**](docs/DefaultApi.md#get_project_api_v2_projects_project_id_get) | **GET** /api/v2/projects/{project_id} | Get Project
*DefaultApi* | [**get_project_default_session_name_api_v2_projects_project_id_default_session_name_get**](docs/DefaultApi.md#get_project_default_session_name_api_v2_projects_project_id_default_session_name_get) | **GET** /api/v2/projects/{project_id}/default_session_name | Get Project Default Session Name
*DefaultApi* | [**get_project_latest_cluster_config_api_v2_projects_project_id_latest_cluster_config_get**](docs/DefaultApi.md#get_project_latest_cluster_config_api_v2_projects_project_id_latest_cluster_config_get) | **GET** /api/v2/projects/{project_id}/latest_cluster_config | Get Project Latest Cluster Config
*DefaultApi* | [**get_provider_metadata_api_v2_clouds_provider_metadata_cloud_id_get**](docs/DefaultApi.md#get_provider_metadata_api_v2_clouds_provider_metadata_cloud_id_get) | **GET** /api/v2/clouds/provider_metadata/{cloud_id} | Get Provider Metadata
*DefaultApi* | [**get_regions_and_zones_api_v2_aws_info_regions_and_zones_get**](docs/DefaultApi.md#get_regions_and_zones_api_v2_aws_info_regions_and_zones_get) | **GET** /api/v2/aws_info/regions_and_zones | Get Regions And Zones
*DefaultApi* | [**get_session_api_v2_sessions_session_id_get**](docs/DefaultApi.md#get_session_api_v2_sessions_session_id_get) | **GET** /api/v2/sessions/{session_id} | Get Session
*DefaultApi* | [**get_session_autoscaler_credentials_api_v2_sessions_session_id_autoscaler_credentials_get**](docs/DefaultApi.md#get_session_autoscaler_credentials_api_v2_sessions_session_id_autoscaler_credentials_get) | **GET** /api/v2/sessions/{session_id}/autoscaler_credentials | Get Session Autoscaler Credentials
*DefaultApi* | [**get_session_cluster_config_api_v2_sessions_session_id_cluster_config_get**](docs/DefaultApi.md#get_session_cluster_config_api_v2_sessions_session_id_cluster_config_get) | **GET** /api/v2/sessions/{session_id}/cluster_config | Get Session Cluster Config
*DefaultApi* | [**get_session_cluster_config_with_session_idle_timeout_api_v2_sessions_session_id_cluster_config_with_session_idle_timeout_get**](docs/DefaultApi.md#get_session_cluster_config_with_session_idle_timeout_api_v2_sessions_session_id_cluster_config_with_session_idle_timeout_get) | **GET** /api/v2/sessions/{session_id}/cluster_config_with_session_idle_timeout | Get Session Cluster Config With Session Idle Timeout
*DefaultApi* | [**get_session_commands_history_api_v2_session_commands_get**](docs/DefaultApi.md#get_session_commands_history_api_v2_session_commands_get) | **GET** /api/v2/session_commands/ | Get Session Commands History
*DefaultApi* | [**get_session_details_api_v2_sessions_session_id_details_get**](docs/DefaultApi.md#get_session_details_api_v2_sessions_session_id_details_get) | **GET** /api/v2/sessions/{session_id}/details | Get Session Details
*DefaultApi* | [**get_session_head_ip_api_v2_sessions_session_id_head_ip_get**](docs/DefaultApi.md#get_session_head_ip_api_v2_sessions_session_id_head_ip_get) | **GET** /api/v2/sessions/{session_id}/head_ip | Get Session Head Ip
*DefaultApi* | [**get_session_history_api_v2_sessions_session_id_history_get**](docs/DefaultApi.md#get_session_history_api_v2_sessions_session_id_history_get) | **GET** /api/v2/sessions/{session_id}/history | Get Session History
*DefaultApi* | [**get_session_ssh_key_api_v2_sessions_session_id_ssh_key_get**](docs/DefaultApi.md#get_session_ssh_key_api_v2_sessions_session_id_ssh_key_get) | **GET** /api/v2/sessions/{session_id}/ssh_key | Get Session Ssh Key
*DefaultApi* | [**get_snapshot_api_v2_snapshots_snapshot_id_get**](docs/DefaultApi.md#get_snapshot_api_v2_snapshots_snapshot_id_get) | **GET** /api/v2/snapshots/{snapshot_id} | Get Snapshot
*DefaultApi* | [**get_snapshot_cluster_config_api_v2_snapshots_snapshot_id_cluster_config_get**](docs/DefaultApi.md#get_snapshot_cluster_config_api_v2_snapshots_snapshot_id_cluster_config_get) | **GET** /api/v2/snapshots/{snapshot_id}/cluster_config | Get Snapshot Cluster Config
*DefaultApi* | [**get_snapshot_files_api_v2_snapshots_snapshot_id_files_get**](docs/DefaultApi.md#get_snapshot_files_api_v2_snapshots_snapshot_id_files_get) | **GET** /api/v2/snapshots/{snapshot_id}/files | Get Snapshot Files
*DefaultApi* | [**get_startup_logs_api_v2_sessions_session_id_startup_logs_get**](docs/DefaultApi.md#get_startup_logs_api_v2_sessions_session_id_startup_logs_get) | **GET** /api/v2/sessions/{session_id}/startup_logs | Get Startup Logs
*DefaultApi* | [**get_startup_logs_archived_api_v2_sessions_session_id_startup_logs_archived_get**](docs/DefaultApi.md#get_startup_logs_archived_api_v2_sessions_session_id_startup_logs_archived_get) | **GET** /api/v2/sessions/{session_id}/startup_logs_archived | Get Startup Logs Archived
*DefaultApi* | [**get_user_info_api_v2_userinfo_get**](docs/DefaultApi.md#get_user_info_api_v2_userinfo_get) | **GET** /api/v2/userinfo/ | Get User Info
*DefaultApi* | [**google_auth_api_v2_oauth2_google_auth_cloud_name_get**](docs/DefaultApi.md#google_auth_api_v2_oauth2_google_auth_cloud_name_get) | **GET** /api/v2/oauth2/google/auth/{cloud_name} | Google Auth
*DefaultApi* | [**google_callback_api_v2_oauth2_google_callback_get**](docs/DefaultApi.md#google_callback_api_v2_oauth2_google_callback_get) | **GET** /api/v2/oauth2/google/callback | Google Callback
*DefaultApi* | [**health_check_api_v2_health_get**](docs/DefaultApi.md#health_check_api_v2_health_get) | **GET** /api/v2/health/ | Health Check
*DefaultApi* | [**heartbeat_api_v2_autosync_sessions_autosync_session_id_heartbeat_post**](docs/DefaultApi.md#heartbeat_api_v2_autosync_sessions_autosync_session_id_heartbeat_post) | **POST** /api/v2/autosync_sessions/{autosync_session_id}/heartbeat | Heartbeat
*DefaultApi* | [**iam_create_api_v2_clouds_gcp_create_iam_project_id_get**](docs/DefaultApi.md#iam_create_api_v2_clouds_gcp_create_iam_project_id_get) | **GET** /api/v2/clouds/gcp/create/iam/{project_id} | Iam Create
*DefaultApi* | [**internal_ip_api_v2_instances_instance_id_internal_ip_get**](docs/DefaultApi.md#internal_ip_api_v2_instances_instance_id_internal_ip_get) | **GET** /api/v2/instances/{instance_id}/internal_ip | Internal Ip
*DefaultApi* | [**invalidate_invitation_api_v2_organization_invitations_invitation_id_invalidate_post**](docs/DefaultApi.md#invalidate_invitation_api_v2_organization_invitations_invitation_id_invalidate_post) | **POST** /api/v2/organization_invitations/{invitation_id}/invalidate | Invalidate Invitation
*DefaultApi* | [**is_running_api_v2_instances_instance_id_is_running_get**](docs/DefaultApi.md#is_running_api_v2_instances_instance_id_is_running_get) | **GET** /api/v2/instances/{instance_id}/is_running | Is Running
*DefaultApi* | [**is_terminated_api_v2_instances_instance_id_is_terminated_get**](docs/DefaultApi.md#is_terminated_api_v2_instances_instance_id_is_terminated_get) | **GET** /api/v2/instances/{instance_id}/is_terminated | Is Terminated
*DefaultApi* | [**kill_session_command_api_v2_session_commands_session_command_id_kill_post**](docs/DefaultApi.md#kill_session_command_api_v2_session_commands_session_command_id_kill_post) | **POST** /api/v2/session_commands/{session_command_id}/kill | Kill Session Command
*DefaultApi* | [**list_application_templates_api_v2_application_templates_get**](docs/DefaultApi.md#list_application_templates_api_v2_application_templates_get) | **GET** /api/v2/application_templates/ | List Application Templates
*DefaultApi* | [**list_builds_api_v2_builds_get**](docs/DefaultApi.md#list_builds_api_v2_builds_get) | **GET** /api/v2/builds/ | List Builds
*DefaultApi* | [**list_clouds_api_v2_clouds_get**](docs/DefaultApi.md#list_clouds_api_v2_clouds_get) | **GET** /api/v2/clouds/ | List Clouds
*DefaultApi* | [**list_decorated_actors_api_v2_decorated_actors_get**](docs/DefaultApi.md#list_decorated_actors_api_v2_decorated_actors_get) | **GET** /api/v2/decorated_actors/ | List Decorated Actors
*DefaultApi* | [**list_decorated_jobs_api_v2_decorated_jobs_get**](docs/DefaultApi.md#list_decorated_jobs_api_v2_decorated_jobs_get) | **GET** /api/v2/decorated_jobs/ | List Decorated Jobs
*DefaultApi* | [**list_decorated_runtime_envs_api_v2_decorated_runtime_envs_get**](docs/DefaultApi.md#list_decorated_runtime_envs_api_v2_decorated_runtime_envs_get) | **GET** /api/v2/decorated_runtime_envs/ | List Decorated Runtime Envs
*DefaultApi* | [**list_decorated_sessions_api_v2_decorated_sessions_get**](docs/DefaultApi.md#list_decorated_sessions_api_v2_decorated_sessions_get) | **GET** /api/v2/decorated_sessions/ | List Decorated Sessions
*DefaultApi* | [**list_invitations_api_v2_organization_invitations_get**](docs/DefaultApi.md#list_invitations_api_v2_organization_invitations_get) | **GET** /api/v2/organization_invitations/ | List Invitations
*DefaultApi* | [**list_organization_collaborators_api_v2_organization_collaborators_get**](docs/DefaultApi.md#list_organization_collaborators_api_v2_organization_collaborators_get) | **GET** /api/v2/organization_collaborators/ | List Organization Collaborators
*DefaultApi* | [**list_organization_project_collaborators_api_v2_projects_project_id_collaborators_organizations_get**](docs/DefaultApi.md#list_organization_project_collaborators_api_v2_projects_project_id_collaborators_organizations_get) | **GET** /api/v2/projects/{project_id}/collaborators/organizations | List Organization Project Collaborators
*DefaultApi* | [**list_project_collaborators_api_v2_projects_project_id_collaborators_users_get**](docs/DefaultApi.md#list_project_collaborators_api_v2_projects_project_id_collaborators_users_get) | **GET** /api/v2/projects/{project_id}/collaborators/users | List Project Collaborators
*DefaultApi* | [**list_projects_api_v2_projects_get**](docs/DefaultApi.md#list_projects_api_v2_projects_get) | **GET** /api/v2/projects/ | List Projects
*DefaultApi* | [**list_sessions_api_v2_sessions_get**](docs/DefaultApi.md#list_sessions_api_v2_sessions_get) | **GET** /api/v2/sessions/ | List Sessions
*DefaultApi* | [**list_snapshots_api_v2_snapshots_get**](docs/DefaultApi.md#list_snapshots_api_v2_snapshots_get) | **GET** /api/v2/snapshots/ | List Snapshots
*DefaultApi* | [**list_web_terminals_api_v2_sessions_session_id_web_terminals_get**](docs/DefaultApi.md#list_web_terminals_api_v2_sessions_session_id_web_terminals_get) | **GET** /api/v2/sessions/{session_id}/web_terminals | List Web Terminals
*DefaultApi* | [**login_user_api_v2_users_login_post**](docs/DefaultApi.md#login_user_api_v2_users_login_post) | **POST** /api/v2/users/login | Login User
*DefaultApi* | [**logout_user_api_v2_users_logout_post**](docs/DefaultApi.md#logout_user_api_v2_users_logout_post) | **POST** /api/v2/users/logout | Logout User
*DefaultApi* | [**non_terminated_nodes_api_v2_instances_non_terminated_nodes_post**](docs/DefaultApi.md#non_terminated_nodes_api_v2_instances_non_terminated_nodes_post) | **POST** /api/v2/instances/non_terminated_nodes | Non Terminated Nodes
*DefaultApi* | [**patch_project_api_v2_projects_project_id_patch**](docs/DefaultApi.md#patch_project_api_v2_projects_project_id_patch) | **PATCH** /api/v2/projects/{project_id} | Patch Project
*DefaultApi* | [**patch_session_api_v2_sessions_session_id_patch**](docs/DefaultApi.md#patch_session_api_v2_sessions_session_id_patch) | **PATCH** /api/v2/sessions/{session_id} | Patch Session
*DefaultApi* | [**patch_snapshot_api_v2_snapshots_snapshot_id_patch**](docs/DefaultApi.md#patch_snapshot_api_v2_snapshots_snapshot_id_patch) | **PATCH** /api/v2/snapshots/{snapshot_id} | Patch Snapshot
*DefaultApi* | [**pool_size_api_v2_instancepools_pool_size_post**](docs/DefaultApi.md#pool_size_api_v2_instancepools_pool_size_post) | **POST** /api/v2/instancepools/pool_size | Pool Size
*DefaultApi* | [**put_session_cluster_config_with_session_idle_timeout_api_v2_sessions_session_id_cluster_config_with_session_idle_timeout_put**](docs/DefaultApi.md#put_session_cluster_config_with_session_idle_timeout_api_v2_sessions_session_id_cluster_config_with_session_idle_timeout_put) | **PUT** /api/v2/sessions/{session_id}/cluster_config_with_session_idle_timeout | Put Session Cluster Config With Session Idle Timeout
*DefaultApi* | [**put_snapshot_cluster_config_api_v2_snapshots_snapshot_id_cluster_config_put**](docs/DefaultApi.md#put_snapshot_cluster_config_api_v2_snapshots_snapshot_id_cluster_config_put) | **PUT** /api/v2/snapshots/{snapshot_id}/cluster_config | Put Snapshot Cluster Config
*DefaultApi* | [**register_autosync_session_api_v2_autosync_sessions_post**](docs/DefaultApi.md#register_autosync_session_api_v2_autosync_sessions_post) | **POST** /api/v2/autosync_sessions/ | Register Autosync Session
*DefaultApi* | [**register_user_api_v2_users_post**](docs/DefaultApi.md#register_user_api_v2_users_post) | **POST** /api/v2/users/ | Register User
*DefaultApi* | [**remove_organization_collaborator_api_v2_organization_collaborators_identity_id_delete**](docs/DefaultApi.md#remove_organization_collaborator_api_v2_organization_collaborators_identity_id_delete) | **DELETE** /api/v2/organization_collaborators/{identity_id} | Remove Organization Collaborator
*DefaultApi* | [**request_instance_from_pool_api_v2_instancepools_request_instance_post**](docs/DefaultApi.md#request_instance_from_pool_api_v2_instancepools_request_instance_post) | **POST** /api/v2/instancepools/request_instance | Request Instance From Pool
*DefaultApi* | [**request_organization_identifiers_api_v2_users_request_organization_identifiers_post**](docs/DefaultApi.md#request_organization_identifiers_api_v2_users_request_organization_identifiers_post) | **POST** /api/v2/users/request_organization_identifiers | Request Organization Identifiers
*DefaultApi* | [**request_password_reset_api_v2_users_request_password_reset_post**](docs/DefaultApi.md#request_password_reset_api_v2_users_request_password_reset_post) | **POST** /api/v2/users/request_password_reset | Request Password Reset
*DefaultApi* | [**reset_password_api_v2_users_reset_password_post**](docs/DefaultApi.md#reset_password_api_v2_users_reset_password_post) | **POST** /api/v2/users/reset_password | Reset Password
*DefaultApi* | [**search_compute_templates_api_v2_compute_templates_search_post**](docs/DefaultApi.md#search_compute_templates_api_v2_compute_templates_search_post) | **POST** /api/v2/compute_templates/search | Search Compute Templates
*DefaultApi* | [**session_get_anyscale_wheel_api_v2_sessions_session_id_anyscale_wheel_get**](docs/DefaultApi.md#session_get_anyscale_wheel_api_v2_sessions_session_id_anyscale_wheel_get) | **GET** /api/v2/sessions/{session_id}/anyscale_wheel | Session Get Anyscale Wheel
*DefaultApi* | [**set_node_tags_api_v2_instances_set_tags_post**](docs/DefaultApi.md#set_node_tags_api_v2_instances_set_tags_post) | **POST** /api/v2/instances/set_tags | Set Node Tags
*DefaultApi* | [**setup_and_initialize_session_api_v2_sessions_session_id_setup_and_initialize_session_post**](docs/DefaultApi.md#setup_and_initialize_session_api_v2_sessions_session_id_setup_and_initialize_session_post) | **POST** /api/v2/sessions/{session_id}/setup_and_initialize_session | Setup And Initialize Session
*DefaultApi* | [**setup_billing_api_v2_clouds_gcp_setup_billing_project_id_get**](docs/DefaultApi.md#setup_billing_api_v2_clouds_gcp_setup_billing_project_id_get) | **GET** /api/v2/clouds/gcp/setup_billing/{project_id} | Setup Billing
*DefaultApi* | [**start_empty_session_api_v2_sessions_start_empty_session_post**](docs/DefaultApi.md#start_empty_session_api_v2_sessions_start_empty_session_post) | **POST** /api/v2/sessions/start_empty_session | Start Empty Session
*DefaultApi* | [**start_nodes_api_v2_instances_start_nodes_post**](docs/DefaultApi.md#start_nodes_api_v2_instances_start_nodes_post) | **POST** /api/v2/instances/start_nodes | Start Nodes
*DefaultApi* | [**start_session_api_v2_sessions_session_id_start_post**](docs/DefaultApi.md#start_session_api_v2_sessions_session_id_start_post) | **POST** /api/v2/sessions/{session_id}/start | Start Session
*DefaultApi* | [**stop_nodes_api_v2_instances_stop_nodes_post**](docs/DefaultApi.md#stop_nodes_api_v2_instances_stop_nodes_post) | **POST** /api/v2/instances/stop_nodes | Stop Nodes
*DefaultApi* | [**stop_session_api_v2_sessions_session_id_stop_post**](docs/DefaultApi.md#stop_session_api_v2_sessions_session_id_stop_post) | **POST** /api/v2/sessions/{session_id}/stop | Stop Session
*DefaultApi* | [**take_snapshot_api_v2_sessions_session_id_take_snapshot_post**](docs/DefaultApi.md#take_snapshot_api_v2_sessions_session_id_take_snapshot_post) | **POST** /api/v2/sessions/{session_id}/take_snapshot | Take Snapshot
*DefaultApi* | [**terminate_nodes_api_v2_instances_terminate_nodes_post**](docs/DefaultApi.md#terminate_nodes_api_v2_instances_terminate_nodes_post) | **POST** /api/v2/instances/terminate_nodes | Terminate Nodes
*DefaultApi* | [**update_cloud_config_api_v2_clouds_cloud_id_config_put**](docs/DefaultApi.md#update_cloud_config_api_v2_clouds_cloud_id_config_put) | **PUT** /api/v2/clouds/{cloud_id}/config | Update Cloud Config
*DefaultApi* | [**update_compute_template_api_v2_compute_templates_compute_template_id_put**](docs/DefaultApi.md#update_compute_template_api_v2_compute_templates_compute_template_id_put) | **PUT** /api/v2/compute_templates/{compute_template_id} | Update Compute Template
*DefaultApi* | [**update_default_cloud_api_v2_organizations_update_default_cloud_post**](docs/DefaultApi.md#update_default_cloud_api_v2_organizations_update_default_cloud_post) | **POST** /api/v2/organizations/update_default_cloud | Update Default Cloud
*DefaultApi* | [**upload_session_command_logs_api_v2_session_commands_session_command_id_upload_logs_post**](docs/DefaultApi.md#upload_session_command_logs_api_v2_session_commands_session_command_id_upload_logs_post) | **POST** /api/v2/session_commands/{session_command_id}/upload_logs | Upload Session Command Logs
*DefaultApi* | [**user_get_temporary_aws_credentials_api_v2_users_temporary_aws_credentials_get**](docs/DefaultApi.md#user_get_temporary_aws_credentials_api_v2_users_temporary_aws_credentials_get) | **GET** /api/v2/users/temporary_aws_credentials | User Get Temporary Aws Credentials
*DefaultApi* | [**user_resend_email_api_v2_users_resend_email_post**](docs/DefaultApi.md#user_resend_email_api_v2_users_resend_email_post) | **POST** /api/v2/users/resend_email | User Resend Email
*DefaultApi* | [**user_server_session_token_api_v2_users_server_session_token_post**](docs/DefaultApi.md#user_server_session_token_api_v2_users_server_session_token_post) | **POST** /api/v2/users/server_session_token | User Server Session Token
*DefaultApi* | [**user_verify_api_v2_users_verify_token_get**](docs/DefaultApi.md#user_verify_api_v2_users_verify_token_get) | **GET** /api/v2/users/verify/{token} | User Verify
*DefaultApi* | [**validate_cluster_api_v2_sessions_validate_cluster_post**](docs/DefaultApi.md#validate_cluster_api_v2_sessions_validate_cluster_post) | **POST** /api/v2/sessions/validate_cluster | Validate Cluster
*DefaultApi* | [**verify_reset_password_token_api_v2_users_reset_password_token_get**](docs/DefaultApi.md#verify_reset_password_token_api_v2_users_reset_password_token_get) | **GET** /api/v2/users/reset_password/{token} | Verify Reset Password Token
*DefaultApi* | [**wait_until_stopped_api_v2_instances_wait_until_stopped_post**](docs/DefaultApi.md#wait_until_stopped_api_v2_instances_wait_until_stopped_post) | **POST** /api/v2/instances/wait_until_stopped | Wait Until Stopped


## Documentation For Models

 - [AWSCredentials](docs/AWSCredentials.md)
 - [AWSNodeOptions](docs/AWSNodeOptions.md)
 - [AWSTag](docs/AWSTag.md)
 - [AWSTagSpecification](docs/AWSTagSpecification.md)
 - [ActorLifetime](docs/ActorLifetime.md)
 - [ActorLogs](docs/ActorLogs.md)
 - [ActorStatus](docs/ActorStatus.md)
 - [ActorlogsResponse](docs/ActorlogsResponse.md)
 - [AddInstancePoolMember](docs/AddInstancePoolMember.md)
 - [AnyscaleAWSAccount](docs/AnyscaleAWSAccount.md)
 - [AnyscaleVersionResponse](docs/AnyscaleVersionResponse.md)
 - [AnyscaleawsaccountResponse](docs/AnyscaleawsaccountResponse.md)
 - [AnyscaleversionresponseResponse](docs/AnyscaleversionresponseResponse.md)
 - [AppConfig](docs/AppConfig.md)
 - [AppConfigConfigSchema](docs/AppConfigConfigSchema.md)
 - [AppconfigResponse](docs/AppconfigResponse.md)
 - [AppliedSnapshot](docs/AppliedSnapshot.md)
 - [ArchivedLogsInfo](docs/ArchivedLogsInfo.md)
 - [ArchivedlogsinfoResponse](docs/ArchivedlogsinfoResponse.md)
 - [AutoscalerCredentials](docs/AutoscalerCredentials.md)
 - [AutoscalercredentialsResponse](docs/AutoscalercredentialsResponse.md)
 - [AutosyncSessionId](docs/AutosyncSessionId.md)
 - [AutosyncsessionidListResponse](docs/AutosyncsessionidListResponse.md)
 - [AutosyncsessionidResponse](docs/AutosyncsessionidResponse.md)
 - [AwsRegionAndZones](docs/AwsRegionAndZones.md)
 - [AwsRegionInfo](docs/AwsRegionInfo.md)
 - [AwscredentialsResponse](docs/AwscredentialsResponse.md)
 - [AwsregionandzonesResponse](docs/AwsregionandzonesResponse.md)
 - [BASEIMAGESENUM](docs/BASEIMAGESENUM.md)
 - [BaseJobStatus](docs/BaseJobStatus.md)
 - [BatchResponseBatchedResultOrganizationInvitationBase](docs/BatchResponseBatchedResultOrganizationInvitationBase.md)
 - [BatchedResultOrganizationInvitationBase](docs/BatchedResultOrganizationInvitationBase.md)
 - [Build](docs/Build.md)
 - [BuildLogResponse](docs/BuildLogResponse.md)
 - [BuildResponse](docs/BuildResponse.md)
 - [BuildStatus](docs/BuildStatus.md)
 - [BuildlogresponseResponse](docs/BuildlogresponseResponse.md)
 - [ChangePasswordParams](docs/ChangePasswordParams.md)
 - [Cloud](docs/Cloud.md)
 - [CloudConfig](docs/CloudConfig.md)
 - [CloudListResponse](docs/CloudListResponse.md)
 - [CloudNameOptions](docs/CloudNameOptions.md)
 - [CloudProviders](docs/CloudProviders.md)
 - [CloudResponse](docs/CloudResponse.md)
 - [CloudTypes](docs/CloudTypes.md)
 - [ClusterConfig](docs/ClusterConfig.md)
 - [ClusterConfigWithSessionIdleTimeout](docs/ClusterConfigWithSessionIdleTimeout.md)
 - [ClusterMonitorResponse](docs/ClusterMonitorResponse.md)
 - [ClusterStatus](docs/ClusterStatus.md)
 - [ClusterconfigResponse](docs/ClusterconfigResponse.md)
 - [ClusterconfigwithsessionidletimeoutResponse](docs/ClusterconfigwithsessionidletimeoutResponse.md)
 - [ClustermonitorresponseResponse](docs/ClustermonitorresponseResponse.md)
 - [ClusterstatusResponse](docs/ClusterstatusResponse.md)
 - [ComputeNodeType](docs/ComputeNodeType.md)
 - [ComputeTemplate](docs/ComputeTemplate.md)
 - [ComputeTemplateConfig](docs/ComputeTemplateConfig.md)
 - [ComputeTemplateQuery](docs/ComputeTemplateQuery.md)
 - [ComputetemplateResponse](docs/ComputetemplateResponse.md)
 - [ComputetemplateconfigResponse](docs/ComputetemplateconfigResponse.md)
 - [CreateAppConfig](docs/CreateAppConfig.md)
 - [CreateAppConfigConfigurationSchema](docs/CreateAppConfigConfigurationSchema.md)
 - [CreateBuild](docs/CreateBuild.md)
 - [CreateComputeTemplate](docs/CreateComputeTemplate.md)
 - [CreateFromGithubOptions](docs/CreateFromGithubOptions.md)
 - [CreateNodesOptions](docs/CreateNodesOptions.md)
 - [CreateOrganizationInvitation](docs/CreateOrganizationInvitation.md)
 - [CreateResponse](docs/CreateResponse.md)
 - [CreateSessionFromSnapshotOptions](docs/CreateSessionFromSnapshotOptions.md)
 - [CreateSessionInDb](docs/CreateSessionInDb.md)
 - [CreateSnapshotOptions](docs/CreateSnapshotOptions.md)
 - [CreateUser](docs/CreateUser.md)
 - [CreateUserProjectCollaborator](docs/CreateUserProjectCollaborator.md)
 - [CreateUserProjectCollaboratorValue](docs/CreateUserProjectCollaboratorValue.md)
 - [DecoratedActor](docs/DecoratedActor.md)
 - [DecoratedApplicationTemplate](docs/DecoratedApplicationTemplate.md)
 - [DecoratedBuild](docs/DecoratedBuild.md)
 - [DecoratedComputeTemplate](docs/DecoratedComputeTemplate.md)
 - [DecoratedComputeTemplateConfig](docs/DecoratedComputeTemplateConfig.md)
 - [DecoratedJob](docs/DecoratedJob.md)
 - [DecoratedRuntimeEnv](docs/DecoratedRuntimeEnv.md)
 - [DecoratedSession](docs/DecoratedSession.md)
 - [DecoratedactorListResponse](docs/DecoratedactorListResponse.md)
 - [DecoratedactorResponse](docs/DecoratedactorResponse.md)
 - [DecoratedapplicationtemplateListResponse](docs/DecoratedapplicationtemplateListResponse.md)
 - [DecoratedapplicationtemplateResponse](docs/DecoratedapplicationtemplateResponse.md)
 - [DecoratedbuildListResponse](docs/DecoratedbuildListResponse.md)
 - [DecoratedbuildResponse](docs/DecoratedbuildResponse.md)
 - [DecoratedcomputetemplateListResponse](docs/DecoratedcomputetemplateListResponse.md)
 - [DecoratedcomputetemplateResponse](docs/DecoratedcomputetemplateResponse.md)
 - [DecoratedjobListResponse](docs/DecoratedjobListResponse.md)
 - [DecoratedjobResponse](docs/DecoratedjobResponse.md)
 - [DecoratedruntimeenvListResponse](docs/DecoratedruntimeenvListResponse.md)
 - [DecoratedruntimeenvResponse](docs/DecoratedruntimeenvResponse.md)
 - [DecoratedsessionListResponse](docs/DecoratedsessionListResponse.md)
 - [DecoratedsessionResponse](docs/DecoratedsessionResponse.md)
 - [Error](docs/Error.md)
 - [ExecuteCommandResponse](docs/ExecuteCommandResponse.md)
 - [ExecuteInteractiveCommandOptions](docs/ExecuteInteractiveCommandOptions.md)
 - [ExecuteShellCommandOptions](docs/ExecuteShellCommandOptions.md)
 - [ExecutecommandresponseResponse](docs/ExecutecommandresponseResponse.md)
 - [ExternalServiceStatus](docs/ExternalServiceStatus.md)
 - [ExternalServiceStatusResponse](docs/ExternalServiceStatusResponse.md)
 - [ExternalTerminalCommand](docs/ExternalTerminalCommand.md)
 - [ExternalservicestatusresponseResponse](docs/ExternalservicestatusresponseResponse.md)
 - [FeatureFlagResponse](docs/FeatureFlagResponse.md)
 - [FeatureflagresponseResponse](docs/FeatureflagresponseResponse.md)
 - [GithubProject](docs/GithubProject.md)
 - [GithubprojectResponse](docs/GithubprojectResponse.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [HeadIp](docs/HeadIp.md)
 - [HeadipResponse](docs/HeadipResponse.md)
 - [IamInstanceProfileSpecification](docs/IamInstanceProfileSpecification.md)
 - [Instance](docs/Instance.md)
 - [InstanceExternalIP](docs/InstanceExternalIP.md)
 - [InstanceID](docs/InstanceID.md)
 - [InstanceInternalIP](docs/InstanceInternalIP.md)
 - [InstanceIsRunning](docs/InstanceIsRunning.md)
 - [InstanceIsTerminated](docs/InstanceIsTerminated.md)
 - [InstanceListResponse](docs/InstanceListResponse.md)
 - [InstancePoolMember](docs/InstancePoolMember.md)
 - [InstanceResponse](docs/InstanceResponse.md)
 - [InstanceStatus](docs/InstanceStatus.md)
 - [InstanceexternalipResponse](docs/InstanceexternalipResponse.md)
 - [InstanceidResponse](docs/InstanceidResponse.md)
 - [InstanceinternalipResponse](docs/InstanceinternalipResponse.md)
 - [InstanceisrunningResponse](docs/InstanceisrunningResponse.md)
 - [InstanceisterminatedResponse](docs/InstanceisterminatedResponse.md)
 - [InstancepoolmemberResponse](docs/InstancepoolmemberResponse.md)
 - [JobsLogs](docs/JobsLogs.md)
 - [JobslogsResponse](docs/JobslogsResponse.md)
 - [JsonPatchOperation](docs/JsonPatchOperation.md)
 - [ListResponseMetadata](docs/ListResponseMetadata.md)
 - [LoginUserParams](docs/LoginUserParams.md)
 - [LogsOutput](docs/LogsOutput.md)
 - [LogsoutputResponse](docs/LogsoutputResponse.md)
 - [MiniBuild](docs/MiniBuild.md)
 - [MiniCloud](docs/MiniCloud.md)
 - [MiniCluster](docs/MiniCluster.md)
 - [MiniComputeTemplate](docs/MiniComputeTemplate.md)
 - [MiniNamespace](docs/MiniNamespace.md)
 - [MiniProject](docs/MiniProject.md)
 - [MiniRuntimeEnvironment](docs/MiniRuntimeEnvironment.md)
 - [MiniUser](docs/MiniUser.md)
 - [NodesOptions](docs/NodesOptions.md)
 - [NonTerminatedNodesOptions](docs/NonTerminatedNodesOptions.md)
 - [Organization](docs/Organization.md)
 - [OrganizationAvailability](docs/OrganizationAvailability.md)
 - [OrganizationCollaborator](docs/OrganizationCollaborator.md)
 - [OrganizationInvitation](docs/OrganizationInvitation.md)
 - [OrganizationInvitationBase](docs/OrganizationInvitationBase.md)
 - [OrganizationPermissionLevel](docs/OrganizationPermissionLevel.md)
 - [OrganizationProjectCollaborator](docs/OrganizationProjectCollaborator.md)
 - [OrganizationProjectCollaboratorValue](docs/OrganizationProjectCollaboratorValue.md)
 - [OrganizationResponse](docs/OrganizationResponse.md)
 - [OrganizationavailabilityResponse](docs/OrganizationavailabilityResponse.md)
 - [OrganizationcollaboratorListResponse](docs/OrganizationcollaboratorListResponse.md)
 - [OrganizationinvitationListResponse](docs/OrganizationinvitationListResponse.md)
 - [OrganizationinvitationResponse](docs/OrganizationinvitationResponse.md)
 - [OrganizationinvitationbaseResponse](docs/OrganizationinvitationbaseResponse.md)
 - [OrganizationprojectcollaboratorListResponse](docs/OrganizationprojectcollaboratorListResponse.md)
 - [PermissionLevel](docs/PermissionLevel.md)
 - [Project](docs/Project.md)
 - [ProjectBase](docs/ProjectBase.md)
 - [ProjectCollaborator](docs/ProjectCollaborator.md)
 - [ProjectCollaboratorValue](docs/ProjectCollaboratorValue.md)
 - [ProjectCollaboratorsPutMessage](docs/ProjectCollaboratorsPutMessage.md)
 - [ProjectCreateMessage](docs/ProjectCreateMessage.md)
 - [ProjectDefaultSessionName](docs/ProjectDefaultSessionName.md)
 - [ProjectDeleteMessage](docs/ProjectDeleteMessage.md)
 - [ProjectListResponse](docs/ProjectListResponse.md)
 - [ProjectPatchMessage](docs/ProjectPatchMessage.md)
 - [ProjectResponse](docs/ProjectResponse.md)
 - [ProjectbaseResponse](docs/ProjectbaseResponse.md)
 - [ProjectcollaboratorListResponse](docs/ProjectcollaboratorListResponse.md)
 - [ProjectdefaultsessionnameResponse](docs/ProjectdefaultsessionnameResponse.md)
 - [ProviderMetadata](docs/ProviderMetadata.md)
 - [ProvidermetadataResponse](docs/ProvidermetadataResponse.md)
 - [PythonModules](docs/PythonModules.md)
 - [QueryPoolSize](docs/QueryPoolSize.md)
 - [RequestInstancePoolMember](docs/RequestInstancePoolMember.md)
 - [RequestOrganizationIdentifiersParams](docs/RequestOrganizationIdentifiersParams.md)
 - [RequestPasswordResetParams](docs/RequestPasswordResetParams.md)
 - [ResetPasswordParams](docs/ResetPasswordParams.md)
 - [Resources](docs/Resources.md)
 - [S3DownloadLocation](docs/S3DownloadLocation.md)
 - [SUPPORTEDBASEIMAGESENUM](docs/SUPPORTEDBASEIMAGESENUM.md)
 - [ServerSessionToken](docs/ServerSessionToken.md)
 - [ServersessiontokenResponse](docs/ServersessiontokenResponse.md)
 - [Session](docs/Session.md)
 - [SessionAutosyncSessionsUpdateMessage](docs/SessionAutosyncSessionsUpdateMessage.md)
 - [SessionCommand](docs/SessionCommand.md)
 - [SessionCommandFinishOptions](docs/SessionCommandFinishOptions.md)
 - [SessionCommandId](docs/SessionCommandId.md)
 - [SessionCommandTypes](docs/SessionCommandTypes.md)
 - [SessionCreateMessage](docs/SessionCreateMessage.md)
 - [SessionDeleteMessage](docs/SessionDeleteMessage.md)
 - [SessionDescribe](docs/SessionDescribe.md)
 - [SessionDetails](docs/SessionDetails.md)
 - [SessionExecuteMessage](docs/SessionExecuteMessage.md)
 - [SessionFinishCommandMessage](docs/SessionFinishCommandMessage.md)
 - [SessionHistoryItem](docs/SessionHistoryItem.md)
 - [SessionId](docs/SessionId.md)
 - [SessionKillCommandMessage](docs/SessionKillCommandMessage.md)
 - [SessionListResponse](docs/SessionListResponse.md)
 - [SessionPatchMessage](docs/SessionPatchMessage.md)
 - [SessionResponse](docs/SessionResponse.md)
 - [SessionSshKey](docs/SessionSshKey.md)
 - [SessionStartingUpData](docs/SessionStartingUpData.md)
 - [SessionState](docs/SessionState.md)
 - [SessionStateChangeMessage](docs/SessionStateChangeMessage.md)
 - [SessionStateData](docs/SessionStateData.md)
 - [SessionStoppingData](docs/SessionStoppingData.md)
 - [SessionUpOptions](docs/SessionUpOptions.md)
 - [SessioncommandListResponse](docs/SessioncommandListResponse.md)
 - [SessioncommandidResponse](docs/SessioncommandidResponse.md)
 - [SessiondescribeResponse](docs/SessiondescribeResponse.md)
 - [SessiondetailsResponse](docs/SessiondetailsResponse.md)
 - [SessionhistoryitemListResponse](docs/SessionhistoryitemListResponse.md)
 - [SessionidResponse](docs/SessionidResponse.md)
 - [SessionsshkeyResponse](docs/SessionsshkeyResponse.md)
 - [SetNodeTagsOptions](docs/SetNodeTagsOptions.md)
 - [SetupInitializeSessionOptions](docs/SetupInitializeSessionOptions.md)
 - [Snapshot](docs/Snapshot.md)
 - [SnapshotCreate](docs/SnapshotCreate.md)
 - [SnapshotCreateMessage](docs/SnapshotCreateMessage.md)
 - [SnapshotDelete](docs/SnapshotDelete.md)
 - [SnapshotDeleteMessage](docs/SnapshotDeleteMessage.md)
 - [SnapshotFiles](docs/SnapshotFiles.md)
 - [SnapshotID](docs/SnapshotID.md)
 - [SnapshotList](docs/SnapshotList.md)
 - [SnapshotListItem](docs/SnapshotListItem.md)
 - [SnapshotPatchMessage](docs/SnapshotPatchMessage.md)
 - [SnapshotProjectFile](docs/SnapshotProjectFile.md)
 - [SnapshotResponse](docs/SnapshotResponse.md)
 - [SnapshotcreateResponse](docs/SnapshotcreateResponse.md)
 - [SnapshotdeleteResponse](docs/SnapshotdeleteResponse.md)
 - [SnapshotfilesResponse](docs/SnapshotfilesResponse.md)
 - [SnapshotidResponse](docs/SnapshotidResponse.md)
 - [SnapshotlistResponse](docs/SnapshotlistResponse.md)
 - [SocketMessageSchemas](docs/SocketMessageSchemas.md)
 - [SocketMessageTypes](docs/SocketMessageTypes.md)
 - [StartEmptySessionResponse](docs/StartEmptySessionResponse.md)
 - [StartSessionOptions](docs/StartSessionOptions.md)
 - [StartemptysessionresponseResponse](docs/StartemptysessionresponseResponse.md)
 - [StopSessionOptions](docs/StopSessionOptions.md)
 - [TakeSnapshotOptions](docs/TakeSnapshotOptions.md)
 - [TextQuery](docs/TextQuery.md)
 - [UpdateComputeTemplate](docs/UpdateComputeTemplate.md)
 - [UpdateOrganizationCollaborator](docs/UpdateOrganizationCollaborator.md)
 - [UpdateProjectCollaborator](docs/UpdateProjectCollaborator.md)
 - [UploadSessionCommandLogsLocations](docs/UploadSessionCommandLogsLocations.md)
 - [UploadsessioncommandlogslocationsResponse](docs/UploadsessioncommandlogslocationsResponse.md)
 - [UserInfo](docs/UserInfo.md)
 - [UserResendEmailOptions](docs/UserResendEmailOptions.md)
 - [UserinfoResponse](docs/UserinfoResponse.md)
 - [ValidationError](docs/ValidationError.md)
 - [WaitUntilStoppedOptions](docs/WaitUntilStoppedOptions.md)
 - [WebTerminal](docs/WebTerminal.md)
 - [WebterminalListResponse](docs/WebterminalListResponse.md)
 - [WebterminalResponse](docs/WebterminalResponse.md)
 - [WorkerNodeType](docs/WorkerNodeType.md)
 - [WriteCloud](docs/WriteCloud.md)
 - [WriteClusterConfig](docs/WriteClusterConfig.md)
 - [WriteProject](docs/WriteProject.md)
 - [WriteSession](docs/WriteSession.md)
 - [WriteSnapshot](docs/WriteSnapshot.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




